@@ -9,7 +9,7 @@ use crate::Value;
 
 #[derive(Debug)]
 pub struct Config {
-    pub peripherals: Vec<Peripheral>,
+    pub peripherals: BTreeMap<u32, Peripheral>,
     pub initial_state: BTreeMap<u32, Value>,
     pub event_processors: Vec<EventProcessor>,
 }
