@@ -118,8 +118,10 @@ impl Producer for BcmChangeBrightnessStateProducer {
     ) -> Result<Option<Packet>, ProducerError> {
         let current_value = match state_manager.get_value(self.state_index) {
             Some(Value::U8(value)) => BcmValue::Single(*value),
-            Some(Value::Rgb(r, g, b)) => BcmValue::Rgb(*r, *g, *b),
-            Some(Value::Rgbw(r, g, b, w)) => BcmValue::Rgbw(*r, *g, *b, *w),
+            Some(Value::Rgb(r, g, b, brightness)) => BcmValue::Rgb(*r, *g, *b, *brightness),
+            Some(Value::Rgbw(r, g, b, w, brightness)) => {
+                BcmValue::Rgbw(*r, *g, *b, *w, *brightness)
+            }
             _ => return Err(ProducerError::WrongStateType),
         };
 
@@ -288,8 +290,10 @@ impl Producer for BcmAnimateBrightnessStateProducer {
     ) -> Result<Option<Packet>, ProducerError> {
         let current_value = match state_manager.get_value(self.state_index) {
             Some(Value::U8(value)) => BcmValue::Single(*value),
-            Some(Value::Rgb(r, g, b)) => BcmValue::Rgb(*r, *g, *b),
-            Some(Value::Rgbw(r, g, b, w)) => BcmValue::Rgbw(*r, *g, *b, *w),
+            Some(Value::Rgb(r, g, b, brightness)) => BcmValue::Rgb(*r, *g, *b, *brightness),
+            Some(Value::Rgbw(r, g, b, w, brightness)) => {
+                BcmValue::Rgbw(*r, *g, *b, *w, *brightness)
+            }
             _ => return Err(ProducerError::WrongStateType),
         };
 
@@ -354,9 +358,10 @@ impl TryDeserialize for BcmAnimateBrightnessStateProducer {
 impl Serialize for BcmValue {
     fn serialize(&self) -> Vec<u8> {
         match *self {
-            BcmValue::Single(value) => vec![0x00, value],
-            BcmValue::Rgb(r, g, b) => vec![0x01, r, g, b],
-            BcmValue::Rgbw(r, g, b, w) => vec![0x02, r, g, b, w],
+            BcmValue::Binary(value) => vec![0x00, if value { 0x01 } else { 0x00 }],
+            BcmValue::Single(value) => vec![0x01, value],
+            BcmValue::Rgb(r, g, b, brightness) => vec![0x02, r, g, b, brightness],
+            BcmValue::Rgbw(r, g, b, w, brightness) => vec![0x03, r, g, b, w, brightness],
         }
     }
 }
@@ -368,20 +373,29 @@ impl TryDeserialize for BcmValue {
         }
 
         match data[0] {
-            0x00 => Ok(Box::new(BcmValue::Single(data[1]))),
-            0x01 => {
-                if data.len() < 4 {
+            0x00 => {
+                if data.len() < 2 {
                     return Err(ConfigSerializerError::WrongSize);
                 }
 
-                Ok(Box::new(BcmValue::Rgb(data[1], data[2], data[3])))
+                Ok(Box::new(BcmValue::Binary(data[1] != 0x00)))
             }
+            0x01 => Ok(Box::new(BcmValue::Single(data[1]))),
             0x02 => {
                 if data.len() < 5 {
                     return Err(ConfigSerializerError::WrongSize);
                 }
 
-                Ok(Box::new(BcmValue::Rgbw(data[1], data[2], data[3], data[4])))
+                Ok(Box::new(BcmValue::Rgb(data[1], data[2], data[3], data[4])))
+            }
+            0x03 => {
+                if data.len() < 6 {
+                    return Err(ConfigSerializerError::WrongSize);
+                }
+
+                Ok(Box::new(BcmValue::Rgbw(
+                    data[1], data[2], data[3], data[4], data[5],
+                )))
             }
             _ => Err(ConfigSerializerError::UnknownEnumVariant),
         }
@@ -416,14 +430,11 @@ mod tests {
             0x00,                                                   // transmitter address
             0x00,                                                   // transmitter address
             0x01,                                                   // index
-            0x01,                                                   // value
-            0x00,                                                   // value
-            0x00,                                                   // value
-            0x00,                                                   // value
+            0x02,                                                   // value
             0x23,                                                   // value
             0x45,                                                   // value
             0x67,                                                   // value
-            0x00,                                                   // value
+            0x89,                                                   // value
         ];
 
         let state_manager = StateManager::new();
@@ -431,7 +442,7 @@ mod tests {
         let producer = BcmChangeBrightnessProducer::new(
             PACKET.device_address,
             0x01,
-            BcmValue::Rgb(0x23, 0x45, 0x67),
+            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
         );
 
         assert_eq!(
@@ -443,19 +454,19 @@ mod tests {
     #[test]
     fn change_brightness_serialize_test() {
         let producer =
-            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67));
+            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67, 0x89));
 
-        let expected_data = vec![0xab, 0xab, 0x01, 0x01, 0x23, 0x45, 0x67];
+        let expected_data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67, 0x89];
 
         assert_eq!(producer.serialize(), expected_data);
     }
 
     #[test]
     fn change_brightness_deserialize_test() {
-        let data = vec![0xab, 0xab, 0x01, 0x01, 0x23, 0x45, 0x67];
+        let data = vec![0xab, 0xab, 0x01, 0x02, 0x23, 0x45, 0x67, 0x89];
 
         let producer =
-            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67));
+            BcmChangeBrightnessProducer::new(0xabab, 0x01, BcmValue::Rgb(0x23, 0x45, 0x67, 0x89));
 
         assert_eq!(
             BcmChangeBrightnessProducer::try_deserialize(&data),
@@ -482,18 +493,15 @@ mod tests {
             0x00,                                                   // transmitter address
             0x00,                                                   // transmitter address
             0x01,                                                   // index
-            0x01,                                                   // value
-            0x00,                                                   // value
-            0x00,                                                   // value
-            0x00,                                                   // value
+            0x02,                                                   // value
             0x23,                                                   // value
             0x45,                                                   // value
             0x67,                                                   // value
-            0x00,                                                   // value
+            0x89,                                                   // value
         ];
 
         let mut state_manager = StateManager::new();
-        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67));
+        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67, 0x89));
 
         let producer = BcmChangeBrightnessStateProducer::new(0xabab, 0x01, 0);
 
@@ -551,14 +559,11 @@ mod tests {
             0xab,                                                    // duration
             0xab,                                                    // duration
             0xab,                                                    // duration
-            0x01,                                                    // target value
-            0x00,                                                    // target value
-            0x00,                                                    // target value
-            0x00,                                                    // target value
+            0x02,                                                    // target value
             0x23,                                                    // target value
             0x45,                                                    // target value
             0x67,                                                    // target value
-            0x00,                                                    // target value
+            0x89,                                                    // target value
         ];
 
         let state_manager = StateManager::new();
@@ -567,7 +572,7 @@ mod tests {
             PACKET.device_address,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67),
+            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
         );
 
         assert_eq!(
@@ -582,11 +587,11 @@ mod tests {
             0xabab,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67),
+            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
         );
 
         let expected_data = vec![
-            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x01, 0x23, 0x45, 0x67,
+            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67, 0x89,
         ];
 
         assert_eq!(producer.serialize(), expected_data);
@@ -595,14 +600,14 @@ mod tests {
     #[test]
     fn animate_brightness_deserialize_test() {
         let data = vec![
-            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x01, 0x23, 0x45, 0x67,
+            0xab, 0xab, 0x01, 0xab, 0xab, 0xab, 0xab, 0x02, 0x23, 0x45, 0x67, 0x89,
         ];
 
         let producer = BcmAnimateBrightnessProducer::new(
             0xabab,
             0x01,
             0xabab_abab,
-            BcmValue::Rgb(0x23, 0x45, 0x67),
+            BcmValue::Rgb(0x23, 0x45, 0x67, 0x89),
         );
 
         assert_eq!(
@@ -634,18 +639,15 @@ mod tests {
             0xab,                                                    // duration
             0xab,                                                    // duration
             0xab,                                                    // duration
-            0x01,                                                    // target value
-            0x00,                                                    // target value
-            0x00,                                                    // target value
-            0x00,                                                    // target value
+            0x02,                                                    // target value
             0x23,                                                    // target value
             0x45,                                                    // target value
             0x67,                                                    // target value
-            0x00,                                                    // target value
+            0x89,                                                    // target value
         ];
 
         let mut state_manager = StateManager::new();
-        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67));
+        state_manager.set_value(0, Value::Rgb(0x23, 0x45, 0x67, 0x89));
 
         let producer = BcmAnimateBrightnessStateProducer::new(0xabab, 0x01, 0xabab_abab, 0);
 
@@ -688,7 +690,7 @@ mod tests {
 
     #[test]
     fn animate_brightness_state_deserialize_wrong_size_test() {
-        let data = vec![0xab, 0xab, 0x01, 0xff, 0xff, 0xff];
+        let data = vec![0xab, 0xab, 0x02, 0xff, 0xff, 0xff];
 
         assert_eq!(
             BcmAnimateBrightnessStateProducer::try_deserialize(&data),
@@ -700,14 +702,14 @@ mod tests {
     fn bcm_value_single_serialize_test() {
         let value = BcmValue::Single(0xab);
 
-        let expected_data = vec![0x00, 0xab];
+        let expected_data = vec![0x01, 0xab];
 
         assert_eq!(value.serialize(), expected_data);
     }
 
     #[test]
     fn bcm_value_single_deserialize_test() {
-        let data = vec![0x00, 0xab];
+        let data = vec![0x01, 0xab];
 
         let expected_value = Box::new(BcmValue::Single(0xab));
 
@@ -716,25 +718,7 @@ mod tests {
 
     #[test]
     fn bcm_value_rgb_serialize_test() {
-        let value = BcmValue::Rgb(0xab, 0xab, 0xab);
-
-        let expected_data = vec![0x01, 0xab, 0xab, 0xab];
-
-        assert_eq!(value.serialize(), expected_data);
-    }
-
-    #[test]
-    fn bcm_value_rgb_deserialize_test() {
-        let data = vec![0x01, 0xab, 0xab, 0xab];
-
-        let expected_value = Box::new(BcmValue::Rgb(0xab, 0xab, 0xab));
-
-        assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
-    }
-
-    #[test]
-    fn bcm_value_rgbw_serialize_test() {
-        let value = BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab);
+        let value = BcmValue::Rgb(0xab, 0xab, 0xab, 0xab);
 
         let expected_data = vec![0x02, 0xab, 0xab, 0xab, 0xab];
 
@@ -742,10 +726,28 @@ mod tests {
     }
 
     #[test]
-    fn bcm_value_rgbw_deserialize_test() {
+    fn bcm_value_rgb_deserialize_test() {
         let data = vec![0x02, 0xab, 0xab, 0xab, 0xab];
 
-        let expected_value = Box::new(BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab));
+        let expected_value = Box::new(BcmValue::Rgb(0xab, 0xab, 0xab, 0xab));
+
+        assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
+    }
+
+    #[test]
+    fn bcm_value_rgbw_serialize_test() {
+        let value = BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab, 0xab);
+
+        let expected_data = vec![0x03, 0xab, 0xab, 0xab, 0xab, 0xab];
+
+        assert_eq!(value.serialize(), expected_data);
+    }
+
+    #[test]
+    fn bcm_value_rgbw_deserialize_test() {
+        let data = vec![0x03, 0xab, 0xab, 0xab, 0xab, 0xab];
+
+        let expected_value = Box::new(BcmValue::Rgbw(0xab, 0xab, 0xab, 0xab, 0xab));
 
         assert_eq!(BcmValue::try_deserialize(&data), Ok(expected_value));
     }
